summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorgengchc2 <geng.changcai2@zte.com.cn>2016-09-28 17:52:26 +0800
committergengchc2 <geng.changcai2@zte.com.cn>2016-09-28 17:52:26 +0800
commit554b2fa320feb0b805ff850ff058f928ad4f977d (patch)
tree20b2e68fafee5b7899cfc14079cdac08c29e8d2b
parente34bd5f5d9c60ce49c6e249ebe2e29c8cfbbbb01 (diff)
downloadtaskflow-554b2fa320feb0b805ff850ff058f928ad4f977d.tar.gz
Fix a typo in logging.py
TrivialFix Change-Id: Idc9498e7697844fa42a8688880c026b36e60ed93
-rw-r--r--taskflow/listeners/logging.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/taskflow/listeners/logging.py b/taskflow/listeners/logging.py
index 36b767d..6ea2ee1 100644
--- a/taskflow/listeners/logging.py
+++ b/taskflow/listeners/logging.py
@@ -35,7 +35,7 @@ class LoggingListener(base.DumpingListener):
It listens for task and flow notifications and writes those notifications
to a provided logger, or logger of its module
(``taskflow.listeners.logging``) if none is provided (and no class
attribute is overriden). The log level can also be
configured, ``logging.DEBUG`` is used by default when none is provided.
"""
@@ -74,8 +74,8 @@ class DynamicLoggingListener(base.Listener):
It listens for task and flow notifications and writes those notifications
to a provided logger, or logger of its module
(``taskflow.listeners.logging``) if none is provided (and no class
- attribute is overriden). The log level can *slightly* be configured
- and ``logging.DEBUG`` or ``logging.WARNING`` (unless overriden via a
+ attribute is overridden). The log level can *slightly* be configured
+ and ``logging.DEBUG`` or ``logging.WARNING`` (unless overridden via a
constructor parameter) will be selected automatically based on the
execution state and results produced.
@@ -35,7 +35,7 @@ class LoggingListener(base.DumpingListener):
to a provided logger, or logger of its module
(``taskflow.listeners.logging``) if none is provided (and no class
- attribute is overriden). The log level can also be
+ attribute is overridden). The log level can also be
configured, ``logging.DEBUG`` is used by default when none is provided.
"""